# Copyright 2018 Eggplant
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from __future__ import print_function

from time import sleep

from aiclient import AIClient, AIClientException

def main():
    url = "http://localhost"
    username = "user@example.com"
    group = "user@example.com"
    password = "Password123"
    model = "MyModel"
    try:
        # Construct the client
        client = AIClient(url, username, password)
        # Run a model
        response = client.run_model(model, group)
        print(response)
        # Check progress until it has completed
        runid = None
        while runid is None:
            response = client.get_progress(response['id'])
            print(response)
            if response['runid'] is not None and response['status'] != 'Paused':
                runid = response['runid']
            else:
                sleep(5)
        # Get the run report
        response = client.get_run_report(model, group)
        # Retrieve the row for the test we just ran
        report = next(r for r in response['rows'] if str(r['id']) == runid)
        print(report)
        # Get the coverage report
        response = client.get_coverage_report(model, group)
        print(response)
    except AIClientException as err:
        print("An exception occurred: {}".format(err))


if __name__ == '__main__':
    main()